---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

We ask the community to always report bugs. Please open a new issue if some other comes up in the conversation. It will help us stay on topic and manage tasks more efficiently.

**Describe the bug**
A clear and concise description of what the bug is.
Example: Reader failing to extract compressed values with SZ

**To Reproduce**
A minimal reproducible example is preferred.
Or Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Desktop (please complete the following information):**
 - OS/Platform: [e.g. Ubuntu 18.04, Cori, Summit]
 - Build [e.g. compiler version gcc 7.4.0, cmake version, build type: static ]

**Additional context**
Add any other context about the problem here.

**Following up**
Was the issue fixed? Please report back.
